Skip to contents

Tasks downstream from a given Connect Task will execute after the provided ConnectTask. When a task is linked as an downstream task, the downstream task also creates an upstream link to the provided task.

Usage

set_downstream(env, ...)

Arguments

env

A ConnectTask environment generated by connect_task that you want to set downstream/dependent tasks for.

...

Any ConnectTasks to make downstream of `env`

Value

Does not return anything, it modified to ConnecTask Environment in-place

Examples

task0 <- connect_task("task0", simulated = TRUE)
task1 <- connect_task("task1", simulated = TRUE)
task2 <- connect_task("task2", simulated = TRUE)

task0 |> set_downstream(task1, task2)
plot(task0)