Class representing a DAG of Connect Tasks
ConnectDAG.RdClass representing a DAG of Connect Tasks
Class representing a DAG of Connect Tasks
Usage
dag <- ConnectDAG$new(name = "dag")Details
This class requires ConnectTasks are added to it, which are themselves linked in a dependency chain. As tasks are added, each tasks' graph is unioned in the DAG's graph. It can then be validated to ensure it is in fact a Directed Acyclic Graph. Once validated, the DAG can orchestrate tasks in Posit Connect.
See also
Other R6 classes:
ConnectTask,
SimTask
Public fields
nameThe user-defined name of this DAG. Useful for organizing multiple DAGs.
pin_nameThe name of pin on Connect where this DAG is saved.
tasksA list of ConnectTasks this DAG is orchestrating.
dag_graphAn igraph object of all linked tasks in this DAG
is_validIndicates if the tasks' dependency chain forms a proper DAG. DO NOT MODIFY DIRECTLY!
run_idA UUID created for an instance of a DAG run
run_startThe time a DAG run started
run_endThe time a DAG run ended
is_completeIndicates if all tasks in this DAG have been evaluated for execution.
Methods
Method set_connect_pin_name()
Sets the name used when using dag_write_connect_pin
Method plot()
Prints a plotly graph of the DAG's graph
Method task_attrs()
Returns a character vector of DAG tasks' specified attribute
Usage
ConnectDAG$task_attrs(task_attr = c("guid", "name", "status"))Method evaluate_validity()
Determines if all added tasks form a valid DAG, setting the `is_valid` field