Simulates a connect task evaluation, with an optional probability for the task to fail.
For a full list of available trigger rules, refer to connect_task.
Usage
sim_task(guid, trigger_rule = "all_success", fail_prob = 0.2)
Arguments
- guid
A scalar character for the guid/name of the task to simulate
- trigger_rule
A scalar character that defines state of dependency (upstream) tasks must be in to execute
- fail_prob
A value between 0 and 1 for the probability of task failure
Value
A SimTask E6 environment
Examples
sim_task0 <- sim_task("foo", trigger_rule = "always", fail_prob = 0)
task_run(sim_task0)